@@ -37,11 +37,11 @@ App::GitHooks - Extensible plugins system for git hooks.
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.1
 
 =cut
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 
 =head1 SYNOPSIS
@@ -494,7 +494,7 @@ sub new
 			terminal              => App::GitHooks::Terminal->new(),
 			arguments             => $arguments,
 			hook_name             => $name,
-			repository            => Git::Repository->new(),
+			repository            => undef,
 			use_colors            => 1,
 		},
 		$class,
@@ -831,6 +831,8 @@ sub get_repository
 {
 	my ( $self ) = @_;
 
+	$self->{'repository'} //= Git::Repository->new();
+
 	return $self->{'repository'};
 }
 
